


<html>
<head>
<title>Zeromin(ぜろみん) - Administration tools for img0ch</title>
<meta http-equiv="Content-Type" content="text/html;charset=utf8" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />

<link rel="stylesheet" type="text/css" href="<?cs var:StaticURI ?>/css/zeromin.css?v=<?cs var:html_escape(SecuredVersion) ?>" />
<link rel="stylesheet" type="text/css" href="<?cs var:StaticURI ?>/css/domTT.css?v=<?cs var:html_escape(SecuredVersion) ?>" />

<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/ajaxupload.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/fastserialize.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/pager.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/tablesorter.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/domTT/domLib.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/domTT/domTT.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/archive.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/banner.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/bbs.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/cgroup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/cap.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/category.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/filter/host.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/filter/ip.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/filter/ngword.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/log/action.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/log/error.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/log/thread.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/metadata.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/pool.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/plugin.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/setting.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/subject.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/system.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/thread.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/ugroup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/user.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>

<script type="text/javascript">
//<[!CDATA[
//<!-- nobanner -->
    var ZEROMIN_CGI_URI = "<?cs var:CGIURI ?>/<?cs var:ZerominScript ?>";
    $(function(){
        $("div", document.getElementById("menuContext")).hide();
        $("input", document.getElementById("login")).get(0).focus();
    });
//]]>
</script>
</head>

<body>

<div id="menuContext">
<div class="hide" id="globalMenu">
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getUser().load()">ユーザー</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getCap().load()">キャップ</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getUgroup().load()">ユーザーグループ</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getCgroup().load()">キャップグループ</a>
<span>|</span>
<a href="javascript:void(0)" onclick="(new Zeromin.Banner(1)).load()">各種編集処理</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getPlugin(0, '').load()">プラグイン</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getSystem(0, '').load()">システム</a>
<span>|</span>
<a href="<?cs var:CGIURI ?>/<?cs var:ZerominScript ?>">ログオフ</a>
</div>
<div class="hide" id="bbsMenu">
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getSubject().load()">スレッド</a>
<span >|</span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getPool().load()">プール</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getArchive().load()">過去ログ</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getSetting()">掲示板設定</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata()">各種編集処理</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getLogError().load()">ログ閲覧</a>
<span>|</span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getPlugin().load()">プラグイン</a>
<span>|</span>
<a href="<?cs var:CGIURI ?>/<?cs var:ZerominScript ?>">ログオフ</a>
</div>
</div>

<div id="header">Zeromin - Administration tools for img0ch</div>


<table cellspacing="0" width="100%" id="layoutContainer">

<tr>

<!-- 左側のメニュー -->
<td class="hide" id="leftContainer">
<div class="hide" id="leftBBSMenu">
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().render('create')">掲示板作成</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getCategory().load()">カテゴリ一覧</a><br />
<a href="javascript:void(0)" onclick="$(document.getElementById('categoryAdd')).toggle()">カテゴリ追加</a><br />
</div>
<div class="hide" id="leftUserMenu">
<a href="javascript:void(0)" onclick="Zeromin.getUser().load()">ユーザー一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getUser().render('create')">ユーザー登録</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftUgroupMenu">
<a href="javascript:void(0)" onclick="Zeromin.getUgroup().load()">ユーザーグループ一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getUgroup().render('create')">ユーザーグループ登録</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftCapMenu">
<a href="javascript:void(0)" onclick="Zeromin.getCap().load()">キャップ一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getCap().render('create')">キャップ登録</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftCgroupMenu">
<a href="javascript:void(0)" onclick="Zeromin.getCgroup().load()">キャップグループ一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getCgroup().render('create')">キャップグループ登録</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftMetaGlobalMenu">
<a href="javascript:void(0)" onclick="(new Zeromin.Banner(1)).load()">告知欄編集</a><br />
<a href="javascript:void(0)" onclick="(new Zeromin.Banner(2)).load()">副告知欄編集</a><br />
<a href="javascript:void(0)" onclick="(new Zeromin.Banner(3)).load()">携帯用告知欄編集</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getFilterIP().setBBS(0, '').load()">書き込み規制(IP)</a><br />
<a href="javascript:void(0)" onclick="$('div#filterIPAdd').toggle()">規制IP追加</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getFilterHost().setBBS(0, '').load()">書き込み規制(ホスト)</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getFilterNGWord().setBBS(0, '').load()">NGワード規制</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getFilterNGWord().render('create')">NGワード追加</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftSystemMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSystem().loadEnvironmentInfo()">システム環境</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getSystem().loadMigrationInfo()">データ移行</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getSystem().loadRepositoryInfo()">レポジトリ</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getLogAction().load()">ユーザー行動履歴</a><br />
</div>
<div class="hide" id="leftMetaBBSLocalMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 1)">ローカルルール編集</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 2)">メタデータ編集</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 3)">フッター編集</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 4)">1000.txt編集</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterIP().load()">書き込み規制(IP)</a><br />
<a href="javascript:void(0)" onclick="$('div#filterIPAdd').toggle()">規制IP追加</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterHost().load()">書き込み規制(ホスト)</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterNGWord().load()">NGワード規制</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterNGWord().render('create')">NGワード追加</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftGlobalPluginMenu">
<a href="javascript:void(0)" onclick="Zeromin.getPlugin().load()">プラグイン一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftSubjectMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getSubject().render('autopool')">一括プーリング</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getSubject().render('import')">スレッドのインポート</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getSubject().render('export')">スレッドのエクスポート</a><br />
<!--
<a href="javascript:void(0)" onclick="Zeromin.getSubject().render('thread924')">特殊スレッド作成</a><br />
<span><hr /></span>
-->
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftPoolMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getPool().load()">プールスレッド一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftArchiveMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getArchive().load()">過去ログ一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftSettingMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">掲示板一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getSetting(null, null, 'main')">基本的な設定</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getSetting(null, null, 'color')">色彩の設定</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getSetting(null, null, 'restrict')">書き込み制限の設定</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getSetting(null, null, 'other')">書き込みその他の設定</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getSetting(null, null, 'upload')">img0ch独自の設定</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftBBSLogMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getLogError().load()">エラーログ一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getLogThread().load()">スレッドログ一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getBBS().getLogAction().load()">ユーザーの行動履歴</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftBBSPluginMenu">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getPlugin().load()">プラグイン一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
<div class="hide" id="leftThreadMenu">
<a href="javascript:void(0)" onclick="Zeromin.getThread().load()">レス一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getThread().getLogError().load()">エラーログ一覧</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getThread().getPlugin().load()">プラグイン一覧</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getSubject().load()">スレッド一覧に戻る</a><br />
<span><hr /></span>
<a href="javascript:void(0)" onclick="Zeromin.getBBS().load()">掲示板一覧に戻る</a><br />
</div>
</td>


<td id="rightContainer">

<!-- トップの関数名 -->
<div class="MethodName" id="globalMethodName">login</div>

<!-- 規制IPアドレスの一覧を表示するコンテナ -->
<div class="hide Container" id="filterIPRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
書き込みを禁止しているIPアドレスを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getFilterIP().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('filterIPTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('filterIPTable'))"
   >全ての選択を解除する</a>

</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">IP</th>
<th class="DetailTitle">範囲</th>
<th class="DetailTitle">備考</th>
</tr>
</thead>
<tbody id="filterIPTable"></tbody>
</table>
<hr />

<div class="alignRight">
<button onclick="Zeromin.getFilterIP().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

<br />

<div class="hide" id="filterIPAdd">
<p>
<div class="MethodName">FILTER_IP - ADD</div>

各項目を設定して「追加」ボタンを押してください。<br />
すでに指定されたIPが登録されている場合は追加登録することが出来ません。
<hr />

<table class="Table" id="filterIPCreate">
<tr>
<td>規制IP</td>
<td><input type="text" name="ip" size="60" /></td>
<td>
<div class="alignRight">
<button onclick="Zeromin.getFilterIP().save()">
&nbsp;&nbsp;登録&nbsp;&nbsp;
</button>
<input id="bbsOnFilterIP" type="hidden" name="bbs" value="" />
</p>
</div>
</td>
</tr>
</table><!-- table#filterIPCreate -->
</div><!-- div#filterIPAdd -->

</div><!-- div#filterIPRoot -->


<!-- 過去ログ一覧を表示するコンテナ -->
<div class="hide Container" id="archiveRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
ここでは過去ログ化されているスレッドを表示しています。<br />
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getBBS().getArchive(null, null, this.value)"
/>
</div>

<div>
<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('archiveTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('archiveTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">スレッド名</th>
<th class="DetailTitle">スレッドキー</th>
<th class="DetailTitle">レス数</td></th>
</tr>
</thead>
<tbody id="archiveTable"></tbody>
</table>

<hr>
<div class="alignRight">
<select name="M" onchange="Zeromin.getArchive().sendCommand(this)">
<option value="null">選択された過去ログを...</option>
<option value="update" title="現在保有する過去ログから一覧(インデックス)を更新します。">一覧更新</option>
<option value="remove" title="指定された過去ログを削除します。一度削除すると二度と復活しませんので注意してください。">削除</option>
</select>
</div>

</div><!-- div#archiveRoot -->


<!-- 告知欄一覧を管理するコンテナ -->
<div class="hide Container" id="bannerRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
ここでは告知(主な目的は広告)を編集することが出来ます。<br>
ここで編集された告知は全ての掲示板に反映されます。
</div>
<ul>
<li>PC用はインデックスのローカルルールの下に配置されます。</li>
<li>携帯用は携帯用インデックスの上部に配置されます。</li>
<li>サブはPC用の下、スレッド一覧の上に配置されます。</li>
</ul>

<table border="0" cellspacing="2" width="100%">
<tr>
<td class="DetailTitle" colspan="2">Preview</td>
</tr>
<tr>
<td colspan="2" align="center">
<div class="hide" id="mainBanner">
<table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="" align="center">
</table>
</div>
<div class="hide" id="mobileBanner">
<table border="1" width="100%" bgcolor="" align="center">
</table>
</div>
</td>
</tr>
<tr>
<td class="DetailTitle">内容</td>
<td><textarea id="bannerContent" rows="10" cols="70" name="content" wrap="off"></textarea></td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getBanner().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td>
</tr>
</table>

<input id="bannerId" type="hidden" name="id" value="" />

</div><!-- div#bannerRoot -->


<!-- 掲示板一覧を管理するコンテナ -->
<div class="hide Container" id="bbsRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
ここでは現在bbss.cgiに存在する掲示板を表示しています。<br />
<a href="#">掲示板の名前(BBS Name)の下に表示されるリンク</a>
をクリックすると掲示板の管理画面に移ります。<br />
<br />
掲示板は存在するのに自分の管轄する掲示板がここに載っていない場合、<br />
まずカテゴリ一覧から「すべて」を選択して表示を行ってください。<br />
それでも載っていない場合は「情報更新」を行ってください。<br />
(「情報更新」権限を持っている人のみ)
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="10"
  onblur="Zeromin.getBBS().load(this.value)"
/>
<select class="categorySelect" name="category"></select>
</div><!-- alignRight -->

<div>
<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('bbsTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('bbsTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">掲示板名</th>
<th class="DetailTitle">カテゴリ名</th>
<th class="DetailTitle">ディレクトリ先</th></tr>
</tr>
</thead>
<tbody id="bbsTable"></tbody>
</table>

<hr />
<div class="alignRight">
<select name="M" onchange="Zeromin.getBBS().sendCommand(this)">
<option value="null">
  選択された掲示板を...
</option>
<option
  value="update_index"
  title="掲示板の「/[bbs]/index.html」と「/[bbs]/subback.html」と「/[bbs]/i/index.html」を更新します。">
  インデックス更新
</option>
<option
  value="repair_upload_file_table"
  title="掲示板のファイル情報キャッシュを更新します。"
>
  キャッシュ更新
</option>
<option
  value="update_subject"
  title="サブジェクトファイル(subject.txt)を更新します。透明削除した後スレッドのレス数を調整するときに使います。">
  サブジェクト更新
</option>
<option
  value="recreate_subject"
  title="サブジェクトファイル(subject.txt)を再生成し、復帰させます。subject.txtが壊れた時、不可視スレッドを発見したときに使います。">
  サブジェクト復帰
</option>
<option
  value="change_category"
  title="指定された掲示板を別のカテゴリに変更します。">
  カテゴリ変更
</option>
<option
  value="update_bbsmenu"
  title="カテゴリからbbsmenu.htmlとbbsmenu2.htmlを更新します。">
  BBSメニュー更新
</option>
<option
  value="repair_bbs_table"
  title="掲示板情報を修復します。存在しないカテゴリが設定されている場合「一般」に戻します。">
  掲示板情報修復
</option>
<!--
<option
  value="calcuration"
  title="掲示板全体のサイズ計算し、キロバイトとメガバイト数で表示します。">
  使用統計
</option>
-->
<option
  value="remove"
  title="「削除」はチェックボックスで指定された掲示板を削除(閉鎖)します。一度削除されたら復活しませんので注意してください。">
  削除
</option>
</select>

</div><!-- div.alignRight-->

</div><!-- div#bbsRoot -->


<!-- 掲示板作成画面を表示するコンテナ -->
<div class="hide Container" id="bbsCreate">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
掲示板を作成します。<br />
<span class="red">*</span>は記入或いは選択必須の項目です。<br />
各項目を設定して[作成]ボタンを押してください。
</div>

<table border="0" cellspacing="2" width="100%">

<tr><td colspan="2"><hr /></td></tr>

<tr>
<td class="DetailTitle">掲示板カテゴリ<span class="red">*</span></td>
<td>
<select class="categorySelect" name="category"></select>
</td>
</tr>

<tr>
<td class="DetailTitle">掲示板ディレクトリ<span class="red">*</span></td>
<td><input type="text" size="60" name="dir" value="jikken" /></td>
</tr>

<tr>
<td class="DetailTitle">掲示板名称</td>
<td><input type=text size="60" name="BBS_TITLE" value="実験＠0ch掲示板" /></td>
</tr>

<tr>
<td class="DetailTitle">掲示板副名称</td>
<td><input type=text size="60" name="BBS_SUBTITLE" value="もるもっとたん。。" />
</td>
</tr>

<tr>
<td class="DetailTitle">掲示板設定継承</td>
<td>
<select class="bbsSelect" name="inherit"></select>
</td>
</tr>

<tr>
<td class="DetailTitle">その他</td>
<td>
<input type="checkbox" name="upload" value="1" checked="checked" />
ファイルのアップロードを行えるようにする
</td>
</tr>

<tr><td colspan="2"><hr /></td></tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getBBS().create()">
&nbsp;&nbsp;作成&nbsp;&nbsp;
</button>
</td>
</tr>

</table>

</div><!-- div#bbsCreate -->


<div class="hide Container" id="capRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
Zerominに登録されているキャップを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getCap().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('capTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('capTable'))"
   >全ての選択を解除する</a>

</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">名前</th>
<th class="DetailTitle">所属グループ名</th>
</tr>
</thead>
<tbody id="capTable"></tbody>
</table>
<hr />

<div class="alignRight">
<button onclick="Zeromin.getCap().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

</div><!-- div#capRoot -->


<div class="hide Container" id="capForm">

<div class="hide State"></div>
<div class="Bread"></div>

<table class="Table" border="0" cellspacing="2">
<tr>
<td colspan="2">
キャップのアカウントを新規に発行します。<br />
<span class="red">*</span>は記入或いは選択必須の項目です。<br />
各項目を設定して[設定]ボタンを押してください。<br />
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">
キャップ表示名
<span class="red">*</span>
</td>
<td>
<input type="text" size="30" name="name" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">
パスワード<span class="red">*</span>
</td>
<td>
<input type="password" size="30" name="pass" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">
パスワード(確認用)<span class="red">*</span>
</td>
<td>
<input type="password" size="30" name="confirm" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">
所属グループ<span class="red">*</span>
</td>
<td>
<select class="capGroupSelect" name="group"></select>
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getCap().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
<input type="hidden" name="id" value="" />
</td>
</tr>
</table>

</div><!-- div#capGroupForm -->


<!-- カテゴリ一覧及び作成を表示する画面 -->
<div class="hide Container" id="categoryRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
ここではカテゴリーを追加したり削除することが出来ます。<br />
カテゴリーを削除したい場合はチェックボックスにチェックを入れて削除をクリックしてください。<br />
<strong class="red">注意：「一般」は削除出来ません！</strong>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="10"
  onblur="Zeromin.getCategory().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('categoryTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('categoryTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">カテゴリ名</th>
<th class="DetailTitle">所属数</th>
</tr>
</thead>
<tbody id="categoryTable"></tbody>
</table>

<hr />
<div class="alignRight">
<button onclick="Zeromin.getCategory().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

<br /><br />

<div class="hide" id="categoryAdd">
<div class="MethodName">Category - ADD</div>
各項目を設定して「追加」ボタンを押してください。<br />
すでに指定されたカテゴリーが存在する場合は追加することが出来ません。
<hr />

<table class="Table" id="categoryCreate">
<tr>
<td>カテゴリ名称</td>
<td><input id="categoryCreateName" type="text" name="name" size="60" /></td>
<td>
<div class="alignRight">
<button onclick="Zeromin.getCategory().create()">
&nbsp;&nbsp;追加&nbsp;&nbsp;
</button>
</div>
</td>
</tr>
</table><!-- table#categoryCreate -->
</div>

</div><!-- div#category -->


<div class="hide Container" id="capGroupRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
Zerominに登録されているキャップグループを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getCgroup().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('capGroupTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('capGroupTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">名前</th>
<th class="DetailTitle">有効範囲</th>
<th class="DetailTitle">所属数</th>
</tr>
</thead>
<tbody id="capGroupTable"></tbody>
</table>
<hr />

<div class="alignRight">
<button onclick="Zeromin.getCgroup().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

</div><!-- div#capGroupRoot -->


<div class="hide Container" id="capGroupForm">

<div class="hide State"></div>
<div class="Bread"></div>

<table class="Table" border="0" cellspacing="2">
<tr>
<td colspan="2">
キャップのグループを設定します。<br />
各情報を入力して[設定]ボタンを押してください。<br />
全ての情報が入力必須です。<br />
<br />
Tip.<br />
権限情報はCTRLキーを押しながらマウスの<br />
左クリックを押すことで個別に選択することが出来ます。<br />
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">グループ名称</td>
<td><input name="name" type="text" size="50" value="" /></td>
</tr>
<tr>
<td class="DetailTitle">有効範囲</td>
<td>
<input type="radio" name="cgroup_all" value="1" />全ての掲示板で有効にする<br />
<input type="radio" name="cgroup_all" value="0" checked="checked" />以下の掲示板で有効にする<br />
<select class="bbsSelect" size="5" name="bbs" multiple="multiple"></select>
</td>
</tr>
<tr>
<td class="DetailTitle">権限</td>
<td>
<!--  p = "privilege" -->
<select name="p" size="10" multiple="multiple">
<option value="1">投稿時の量にかかわる制限の解除</option>
<option value="2">PROXY経由での書き込みの許可</option>
<option value="4">無制限のスレッド作成許可</option>
<option value="8">SAMBA24制限の解除</option>
<option value="16">連続投稿制限の解除</option>
<option value="32">二重投稿制限の解除</option>
<option value="64">キャップのみの掲示板に対するスレッド作成の許可</option>
<option value="128">キャップのみの掲示板に対する投稿の許可</option>
<option value="256">IDの非表示(ID:???)</option>
<option value="512">名前の後の★の付加</option>
</select>
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getCgroup().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
<input type="hidden" name="id" value="" />
</table>

</div><!-- div#capGroupForm -->


<!-- 規制ホストの一覧を表示するコンテナ -->
<div class="hide Container" id="filterHostRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
書き込みを禁止しているホストを表示しています。<br />
<ul>
<li>正規表現を使って規制を行うことが出来ます。</li>
<li>規制情報は掲示板ごとと掲示板全体に分かれ、別々に保存されます。</li>
</ul>
</div>
<div>
<table border="0" cellspacing="2" width="100%">
<td class="DetailTitle">規制ホスト</td>
<td><textarea name="regexp" cols="70" rows="10"></textarea></td>
<tr><td colspan="2"><hr /></td></tr>
<tr><td colspan="2" align="right">
<button onclick="Zeromin.getFilterHost().save()">
&nbsp;&nbsp;保存&nbsp;&nbsp;
</button>
<input id="bbsOnFilterHost" type="hidden" name="bbs" value="" />
</td></tr>
</table>
</div>

</div><!-- div#filterIPRoot -->


<div class="hide Container" id="logActionRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>

Zerominでの各ユーザーの行動履歴を表示しています。
下のリンクからログの表示方法を変更することが出来ます。

<div>
<a href="javascript:void(0)"
  onclick="Zeromin.getLogAction().setBy('today').load()">
今日の行動履歴を表示する
</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getLogAction().setBy('month').load()">
今月の行動履歴を表示する
</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getLogAction().setBy('all').load()">
全ての行動履歴を表示する
</a>
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getLogAction().load(this.value)"
/>
</div><!-- alignRight -->
<hr />
</div>

<table class="Table">
<thead>
<tr>
<th class="DetailTitle">内容</th>
<th class="DetailTitle">ユーザー名</th>
<th class="DetailTitle">時刻</th>
<th class="DetailTitle">IPアドレス</th>
</tr>
</thead>
<tbody id="logActionTable"></tbody>
</table>

</div><!-- div#logActionRoot -->


<div class="hide Container" id="logErrorRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>

過去に発生したエラー記録を表示しています。<br />
下のリンクからログの表示方法を変更することが出来ます。

<div>
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getLogError().setBy('today').load()">
今日のエラー履歴を表示する
</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getLogError().setBy('month').load()">
今月のエラー履歴を表示する
</a><br />
<a href="javascript:void(0)"
  onclick="Zeromin.getBBS().getLogError().setBy('all').load()">
全てのエラー履歴を表示する
</a>
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getBBS().getLogError().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
</div>

<table class="Table">
<thead>
<tr>
<th class="DetailTitle">エラー内容</th>
<th class="DetailTitle">IPアドレス</th>
<th class="DetailTitle">時刻</th>
<th class="DetailTitle">スレッド名</th>
</tr>
</thead>
<tbody id="logErrorTable"></tbody>
</table>

</div><!-- div#logErrorRoot -->


<div class="hide Container" id="logThreadRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
スレッド作成ログを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getBBS().getLogError().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
</div>

<table class="Table">
<thead>
<tr>
<th class="DetailTitle">IPアドレス</th>
<th class="DetailTitle">IPグループ番号</th>
<th class="DetailTitle">時刻</th>
</tr>
</thead>
<tbody id="logThreadTable"></tbody>
</table>

</div><!-- div#logThreadRoot -->


<!-- ログイン画面を表示するコンテナ -->
<div class="Container" id="login">

<form action="#" method="post" onsubmit="login(); return false;">
<center>

<div class="hide Failed" id="loginError"></div>
<div class="hide Process" id="loginProcess"></div>
<br />
<br />
<br />
<br />
<br />

<noscript>
<div>
JavaScriptが無効になっています。<br />
JavaScriptを有効にしてから再リロードを行ってください。
</div>
</noscript>

<table>
<tr>
<td>ユーザ名</td>
<td><input type="text" name="userName" size="30" /></td>
</tr>
<tr>
<td>パスワード</td>
<td><input type="password" name="userPass" size="30" /></td>
</tr>
<tr>
<td colspan="2" align="center">
<hr />
<input type=submit value="　ログイン　">
</td>
</tr>
</table>

<br /><br /><br /><br /><br /><br />

<div class="alignCenter">
<strong>Zeromin - Administration tools for img0ch</strong><br />
<strong>Design based on 0ch ver 4.0</strong>
</div><!-- alignCenter -->

<br /><br /><br /><br />

</center>
</form>

</div><!-- div#loginForm -->


<!-- NGワードの一覧を表示するコンテナ -->
<div class="hide Container" id="filterNGWordRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
Zerominに登録されているユーザーを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getFilterNGWord().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('filterNGWordTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('filterNGWordTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">禁止単語</th>
<th class="DetailTitle">対処方法</th>
<th class="DetailTitle">置換単語</th>
</tr>
</thead>
<tbody id="filterNGWordTable"></tbody>
</table>
<hr />

<div class="alignRight">
<button onclick="Zeromin.getFilterNGWord().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

</div><!-- div#userRoot -->


<div class="hide Container" id="filterNGWordForm">

<div class="hide State"></div>
<div class="Bread"></div>

<table class="Table" border="0" cellspacing="2">
<tr>
<td colspan="2">
指定された単語をNGワードとして登録します。<br />
<span class="red">*</span>は記入或いは選択必須の項目です。<br />
各項目を設定して[設定]ボタンを押してください。
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">
禁止単語<span class="red">*</span>
</td>
<td>
<input type="text" size="30" name="entry" value="" /></td>
</tr>
<tr>
<td class="DetailTitle">
対処方法<span class="red">*</span>
</td>
<td>
<select name="type">
<option value="1" selected="selected">書き込みの禁止</option>
<option value="2">禁止単語の削除</option>
<option value="4">置換単語への置換</option>
</select>
</tr>
<tr>
<td class="DetailTitle">
置換単語
</td>
<td>
<input type="text" size="30" name="to" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">有効範囲</td>
<td>
<select class="bbsSelect" name="bbs"></select>
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr><td colspan="2" align="right">
<button onclick="Zeromin.getFilterNGWord().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
<input type="hidden" name="id" value="" />
</td></tr>
</table>

</div><!-- div#filterNGWordForm -->


<!-- 掲示板のヘッダー、メタデータ、フッターを管理するコンテナ -->
<div class="hide Container" id="metadataRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
ローカルルール、メタデータ、フッターを編集します。<br />
ローカルルール及びフッターはプレビューが可能です。
</div>

<table border="0" cellspacing="2" width="100%">
<tr>
<td class="DetailTitle" colspan="2">Preview</td>
</tr>
<tr>
<td colspan="2" align="center">
<div class="hide" id="header">
<table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="" align="center">
</table>
</div>
<div class="hide" id="footer">
<table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="" align="center">
</table>
</div>
</td>
</tr>
<tr>
<td class="DetailTitle">内容</td>
<td><textarea id="metadataContent" rows="10" cols="70" name="content" wrap="off"></textarea></td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getMetadata().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td>
</tr>
</table>

<input id="metadataId" type="hidden" name="id" value="" />

</div><!-- div#bannerRoot -->


<!-- スレッド終了を告知するレスを管理するコンテナ -->
<div class="hide Container" id="threadEndRoot">

<div class="State"></div>
<div class="Bread"></div>

<div>
ここではスレッド終了時のレスを編集することが出来ます。<br />
名前欄、メール欄、日付、本文が変更可能です。タグは利用出来ません。<br />
日付の書式は「Over (数字) Thread」とする必要があります。<br />
これ以外の書式で保存することは出来ません。<br />
</div>

<table border="0" cellspacing="2" width="100%">
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">名前</td>
<td><input type="text" size="50" value="" name="FROM" /></td>
</tr>
<tr>
<td class="DetailTitle">メール</td>
<td><input type="text" size="50" value="" name="mail" /></td>
</tr>
<tr>
<td class="DetailTitle">日付・ID</td>
<td><input type="text" size="50" value="" name="date" /></td>
</tr>
<tr>
<td class="DetailTitle">本文</td>
<td><textarea name="MESSAGE" cols="70" rows="10"></textarea></td>
</tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getMetadata().save('threadEndRoot')">
&nbsp;&nbsp;保存&nbsp;&nbsp;
</button>
</td>
</tr>
</table>

<input id="metadataId" type="hidden" name="id" value="" />

</div><!-- div#threadEndRoot -->


<div class="hide Container" id="pluginRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
インストールされたプラグインを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getPlugin().load(this.value)"
/>
<select class="pluginSelect" name="plugin"
  onchange="Zeromin.getPlugin().load(null, this.options[this.selectedIndex].value)"></select>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('pluginTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('pluginTable'))"
   >全ての選択を解除する</a>

</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">プラグイン名</th>
<th class="DetailTitle">関数</th>
<th class="DetailTitle">呼出箇所</th>
</tr>
</thead>
<tbody id="pluginTable"></tbody>
</table>
<hr />

<div class="alignRight">
<select name="M" onchange="Zeromin.getPlugin().save(this.value)">
<option value="null">実行方法を選択してください</option>
<option value="save" title="">選択されたプラグインを有効にする</option>
<option value="search" title="">新規プラグインを検索する</option>
</select>
</div>

</div><!-- div#pluginRoot -->

<div class="hide Container" id="pluginConfigRoot">

<div class="hide State"></div>

<div id="pluginConfigHTML">
</div>

<div>
<button onclick="Zeromin.getPlugin().saveConfig()">
&nbsp;&nbsp;保存&nbsp;&nbsp;
</button>
<input type="hidden" name="type" value="save" />
</div>

</div>


<!-- スレッド一覧を表示するコンテナ -->
<div class="hide Container" id="poolRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
ここではプールに存在するスレッドを表示しています。<br />
</a>
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getBBS().getPool(null, null, this.value)"
/>
</div>

<div>
<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('poolTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('poolTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">スレッド名</th>
<th class="DetailTitle">スレッドキー</th>
<th class="DetailTitle">レス数</td></th>
</tr>
</thead>
<tbody id="poolTable"></tbody>
</table>

<hr>
<div class="alignRight">
<select name="M" onchange="Zeromin.getPool().sendCommand(this)">
<option value="null">選択されたスレッドを...</option>
<option value="archive" title="指定されたプールスレッドを過去ログに変換します。元のプールスレッドは削除されません。">過去ログ化</option>
<option value="restore" title="指定されたプールスレッドを現行スレッドとして復帰させます。">復帰</option>
<option value="remove" title="指定されたプールスレッドを削除します。削除すると二度と復活しませんので注意してください。">削除</option>
</select>
</div>

</div><!-- div#poolRoot -->


<!-- 掲示板設定を表示するコンテナ -->
<div class="hide Container" id="settingRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div class="hide Setting" id="settingMain">
<table cellspcing="2" width="100%">
<tr><td colspan="2">
掲示板の基礎設定です。<br />
各設定値を入力して「設定」ボタンを押してください。<br />
<br />
値を空欄にしたい場合はスペースキー等を使って<br />
空白文字を入れてください。
</td></tr>
<tr><td colspan="2"><hr></td></tr>
<tr><td class="DetailTitle">掲示板の名前</td>
<td><input type="text" size="80" name="BBS_TITLE" value=""></td></tr>
<tr><td class="DetailTitle">サブタイトル</td>
<td><input type="text" size="80" name="BBS_SUBTITLE" value=""></td></tr>
<tr><td class="DetailTitle">index看板画像</td>
<td><input type="text" size="80" name="BBS_TITLE_PICTURE" value=""></td></tr>
<tr><td class="DetailTitle">index看板リンク</td>
<td><input type="text" size="80" name="BBS_TITLE_LINK" value=""></td></tr>
<tr><td class="DetailTitle">index背景画像</td>
<td><input type="text" size="80" name="BBS_BG_PICTURE" value=""></td></tr>
<tr><td class="DetailTitle">名無しさん</td>
<td><input type="text" size="80" name="BBS_NONAME_NAME" value=""></td></tr>
<tr><td class="DetailTitle">削除文言</td>
<td><input type="text" size="80" name="BBS_DELETE_NAME" value=""></td></tr>
<tr><td class="DetailTitle">Cookieの有効パス</td>
<td><input type="text" size="80" name="BBS_COOKIE_PATH" value=""></td></tr>
<tr><td class="DetailTitle">クッション先</td>
<td><input type="text" size="80" name="BBS_REFERER_CUSHION" value=""></td></tr>
<tr><td class="DetailTitle">トリップの桁数</td>
<td><input type="text" size="80" name="BBS_TRIPCOLUMN" value=""></td></tr>
<tr><td class="DetailTitle">掲示板読取専用</td>
<td colspan="3">
<input type="radio" name="BBS_READONLY" value="on" />読取専用<br />
<input type="radio" name="BBS_READONLY" value="caps" />キャップのみ書き込み可<br />
<input type="radio" name="BBS_READONLY" value="none" />書き込み可<br />
</td></tr>
<tr><td class="DetailTitle">使用するテンプレート名</td>
<td><input type="text" size="80" name="BBS_TEMPLATE" value=""></td></tr>
<tr><td class="DetailTitle">最大レス数</td>
<td><input type="text" size="80" name="BBS_RES_MAX" value=""></td></tr>
<tr><td colspan="2"><hr></td></tr>
<tr><td colspan="2" align="right">
<button onclick="Zeromin.getSetting().save('div#settingMain')">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td></tr>
</table>

</div>

<div class="hide Setting" id="settingColor">
<table cellspcing="2" width="100%">

<tr><td colspan="6">
掲示板の配色設定です。<br />
各設定色を入力して「設定」ボタンを押してください。<br />
値を入れるごとに自動的に対応するプレビューが更新されます。<br />
</td></tr>

<tr><td colspan="6"><hr /></td></tr>
<tr>
<td class="DetailTitle">index背景色</td>
<td>
<input type="text" size="10" name="BBS_BG_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
/>
</td>
<td class="preview_of_BBS_BG_COLOR"></td>
<td class="DetailTitle">テキスト色</td>
<td>
<input type="text" size="10" name="BBS_TEXT_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_TEXT_COLOR">テキスト</td></tr>
<tr><td class="DetailTitle">indexメニュー背景色</td>
<td>
<input type="text" size="10" name="BBS_MENU_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
/>
</td>
<td class="preview_of_BBS_MENU_COLOR"></td>
<td class="DetailTitle">名前色</td>
<td>
<input type="text" size="10" name="BBS_NAME_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_NAME_COLOR">名前</td></tr>
<tr><td class="DetailTitle">スレッド作成背景色</td>
<td>
<input type="text" size="10" name="BBS_MAKETHREAD_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
/>
</td>
<td class="preview_of_BBS_MAKETHREAD_COLOR"></td>
<td class="DetailTitle">リンク色</td>
<td>
<input type="text" size="10" name="BBS_LINK_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_LINK_COLOR">リンク</td></tr>
<tr><td class="DetailTitle">スレッド背景色</td>
<td>
<input type="text" size="10" name="BBS_THREAD_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, false)"
/>
</td>
<td class="preview_of_BBS_THREAD_COLOR"></td>
<td class="DetailTitle">リンク色(アンカー時)</td>
<td>
<input type="text" size="10" name="BBS_ALINK_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_ALINK_COLOR">リンク(アンカー)</td></tr>
<tr><td class="DetailTitle">indexタイトル色</td>
<td>
<input type="text" size="10" name="BBS_TITLE_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_TITLE_COLOR">indexタイトル</td>
<td class="DetailTitle">リンク色(訪問済み)</td>
<td>
<input type="text" size="10" name="BBS_VLINK_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_VLINK_COLOR">リンク(訪問済み)</td>
</tr>
<tr>
<td class="DetailTitle">スレッドタイトル色</td>
<td>
<input type="text" size="10" name="BBS_SUBJECT_COLOR" value=""
  onkeypress="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
  onblur="Zeromin.getSetting().updateColorPreview(this.name, this.value, true)"
/>
</td>
<td class="preview_of_BBS_SUBJECT_COLOR">スレッドタイトル</td>
</tr>
<tr>
<td class="DetailTitle">
typeに適用するテーマ名<br />
(BBS_TEMPLATEをtypeにする必要があります。)
</td>
<td colspan="2"><input type="text" size="25" name="BBS_TYPE_THEME" value=""></td>
<td colspan="3"></td>
</tr>
<tr><td colspan="6"><hr /></td></tr>

<tr>
<td class="DetailTitle" colspan="3">indexプレビュー</td>
<td class="DetailTitle" colspan="3">スレッドプレビュー</td>
</tr>
<tr>
<td colspan="3">
<center class="preview_of_BBS_BG_COLOR">
<span class="preview_of_BBS_TITLE_COLOR">indexタイトル</span><br />
<table class="preview_of_BBS_MENU_COLOR" width="100%" cellspacing="7" border="1">
<td class="preview_of_BBS_TEXT_COLOR">ヘッダ</td>
</table><br />
<table class="preview_of_BBS_MENU_COLOR" width="100%" cellspacing="7" border="1">
<td class="preview_of_BBS_TEXT_COLOR">メニュー</td>
</table><br />
<table class="preview_of_BBS_THREAD_COLOR" width="100%" cellspacing="7" border="1">
<td>
<div align="right"><u class="preview_of_BBS_LINK_COLOR">■▲▼</u></div>
<b><span class="preview_of_BBS_TEXT_COLOR">【1:1】</span>
<font class="preview_of_BBS_SUBJECT_COLOR" size="+2">スレッドタイトル</span></b>
</td>
</table>
<br />
<table class="preview_of_BBS_MAKETHREAD_COLOR" width="100%" cellspacing="7" border="1">
<td class="preview_of_BBS_TEXT_COLOR">スレッド作成</td>
</table><br />
</center>
</td>
<dl>
<td class="preview_of_BBS_THREAD_COLOR" colspan="3" valign="top">
<span class="preview_of_BBS_SUBJECT_COLOR" size="+1">スレッドタイトル</span>
<br /><br />
<dt class="preview_of_BBS_TEXT_COLOR">1：<b><span class="preview_of_BBS_NAME_COLOR">BBS_NONAME_NAME</span></b>
：2000/01/01(土) 00:00:00 ID:???</dt><dd>
<span class="preview_of_BBS_TEXT_COLOR">以下はリンクカラーのテストです。</span>
<br /><br />
<span class="preview_of_BBS_LINK_COLOR"><u>http://www.example.com/path/to/bbs1/</u></span>
<span class="preview_of_BBS_TEXT_COLOR">(訪問前)</span><br />
<span class="preview_of_BBS_VLINK_COLOR"><u>http://www.example.com/path/to/bbs2/</u></span>
<span class="preview_of_BBS_TEXT_COLOR">(訪問後)</span><br />
</dd>
</td>
</dl>
</tr>

<tr><td colspan="6"><hr /></td></tr>
<tr><td colspan="6" align="right">
<button onclick="Zeromin.getSetting().save('div#settingColor')">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td></tr>

</table><br />

</div>

<div class="hide Setting" id="settingRestrict">
<table cellspcing="2" width="100%">
<tr><td colspan="4">
掲示板の制限設定です。<br>
各設定値を入力して「設定」ボタンを押してください。
<ul>
<li>「プロクシチェック」はシステム設定の「PORT_CHECK」が有効になっていなければ設定しても無効となります。</li>
<li>「海外のホスト規制」は書き込みしたホストのドメインが日本(jp)でなければ書き込みを出来なくさせる設定です。</li>
<li>ID表示は複数選択が可能ですが、適用順は「ホスト表示」、「ID表示なし」、「強制ID」、「任意ID(何も選択しなかった場合)」の順番です。</li>
</ul>
</td></tr>
<tr><td colspan="4"><hr></td></tr>
<tr><td class="DetailTitle">サブジェクト文字数</td>
<td><input type="text" size="10" name="BBS_SUBJECT_COUNT" value="" /></td>
<td class="DetailTitle">名無しチェック</td>
<td><input type="checkbox" name="NANASHI_CHECK" value="checked" />チェック有り</td></tr>
<tr><td class="DetailTitle">名前文字数</td>
<td><input type="text" size="10" name="BBS_NAME_COUNT" value="" /></td>
<td class="DetailTitle">プロクシチェック</td>
<td><input type="checkbox" name="BBS_PROXY_CHECK" value="checked" />チェック有り</td></tr>
<tr><td class="DetailTitle">メール文字数</td>
<td><input type="text" size="10" name="BBS_MAIL_COUNT" value="" /></td>
<td class="DetailTitle">DSBLによるレス規制</td>
<td><input type="checkbox" name="BBS_OVERSEA_PROXY" value="checked" />チェック有り</td></tr>
<tr><td class="DetailTitle">本文文字数</td>
<td><input type="text" size="10" name="BBS_MESSAGE_COUNT" value="" /></td>
<td class="DetailTitle">DSBLによるスレッド立て規制</td>
<td><input type="checkbox" name="BBS_OVERSEA_THREAD" value="checked" />チェック有り</td></tr>
<tr><td class="DetailTitle">スレッド作成ログ保存数</td>
<td><input type="text" size="10" name="BBS_THREAD_TATESUGI" value="" /></td>
<td class="DetailTitle">海外のホスト規制</td>
<td><input type="checkbox" name="BBS_JP_CHECK" value="checked" />規制有り</td></tr>
<tr><td class="DetailTitle">書き込みログ保存数</td>
<td><input type="text" size="10" name="timecount" value="" /></td>
<td class="DetailTitle">トマト</td>
<td><input type="checkbox" name="BBS_RAWIP_CHECK" value="checked" />トマト表示</td></tr>
<tr><td class="DetailTitle">連続書き込み回数</td>
<td><input type="text" size="10" name="timeclose" value="" /></td>
<td class="DetailTitle">PC・携帯識別子</td>
<td><input type="checkbox" name="BBS_SLIP" value="checked" />付加する</td></tr>
<tr><td class="DetailTitle">１スレッドの最大サイズ</td>
<td><input type="text" size="10" name="BBS_DATMAX" value="" /></td>
<td class="DetailTitle">ID表示:強制IDを適用する</td>
<td><input type="checkbox" name="BBS_FORCE_ID" value="checked" />有効</td></tr>
<tr><td class="DetailTitle">一行あたりの最大文字数</td>
<td><input type="text" size="10" name="BBS_COLUMN_NUMBER" value="" /></td>
<td class="DetailTitle">ID表示:ID表示無しを適用する</td>
<td><input type="checkbox" name="BBS_NO_ID" value="checked" />有効</td></tr>
<tr><td></td><td></td>
<td class="DetailTitle">ID表示:IDの代わりに接続元を表示する</td>
<td><input type="checkbox" name="BBS_DISP_IP" value="checked" />有効</td></tr>
<tr><td colspan="4"><hr></td></tr>
<tr><td colspan="4" align="right">
<button onclick="Zeromin.getSetting().save('div#settingRestrict')">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td></tr>
</table>

</div>

<div class="hide Setting" id="settingOther">
<table cellspcing="2" width="100%">
<tr><td colspan="4">
掲示板のその他の設定です。<br>
各設定値を入力して「設定」ボタンを押してください。
<ul>
<li>「文字参照変換」は現在使われていません。</li>
<li>「曜日文字」は「日/月/火/水/木/金/土」のようにスラッシュで区切って設定してください。</li>
</ul>
</td></tr>
<tr><td colspan="4"><hr></td></tr>

<tr><td class="DetailTitle">indexスレッドプレビュー数</td>
<td><input type="text" size="8" name="BBS_THREAD_NUMBER" value="" /></td>
<td class="DetailTitle">文字参照変換</td>
<td><input type="checkbox" name="BBS_UNICODE" value="change" />変換する</td></tr>
<tr><td class="DetailTitle">indexプレビューレス数</td>
<td><input type="text" size="8" name="BBS_CONTENTS_NUMBER" value="" /></td>
<td class="DetailTitle">cookie確認</td>
<td><input type="checkbox" name="SUBBBS_CGI_ON" value="checked" />確認あり</td></tr>
<tr><td class="DetailTitle">indexレス内容表示行数</td>
<td><input type="text" size="8" name="BBS_LINE_NUMBER" value="" /></td>
<td class="DetailTitle">&nbsp;&nbsp;&nbsp;&nbsp;名前cookie保存</td>
<td><input type="checkbox" name="BBS_NAMECOOKIE_CHECK" value="checked" />保存</td></tr>
<tr><td class="DetailTitle">indexメニュー数</td>
<td><input type="text" size="8" name="BBS_MAX_MENU_THREAD" value="" /></td>
<td class="DetailTitle">&nbsp;&nbsp;&nbsp;&nbsp;メールcookie保存</td>
<td><input type="checkbox" name="BBS_MAILCOOKIE_CHECK" value="checked" />保存</td></tr>
<tr><td class="DetailTitle">携帯からのスレッドプレビュー数</td>
<td><input type="text" size="8" name="BBS_MB_THREAD_NUMBER" value="" /></td>
<td class="DetailTitle">スレッド作成画面</td>
<td><input type="checkbox" name="BBS_PASSWORD_CHECK" value="checked" />別画面</td></tr>
<tr><td class="DetailTitle">携帯からのプレビューレス数</td>
<td><input type="text" size="8" name="BBS_MB_CONTENTS_NUMBER" value="" /></td>
<td class="DetailTitle">スレッド作成確認画面</td>
<td><input type="checkbox" name="BBS_NEWSUBJECT" value="checked" />確認あり</td></tr>
<tr><td class="DetailTitle">携帯からのレス内容表示行数</td>
<td><input type="text" size="8" name="BBS_MB_LINE_NUMBER" value="" /></td>
<td class="DetailTitle">キャップのみスレッド作成可能</td>
<td><input type="checkbox" name="BBS_THREADCAPONLY" value="checked" />有効</td>
<tr><td class="DetailTitle">曜日文字</td>
<td><input type="text" size="20" name="BBS_YMD_WEEKS" value="" /></td></tr>
<td colspan="2"></td></tr>

<tr><td colspan="4"><hr></td></tr>
<tr><td colspan="4" align="right">
<button onclick="Zeromin.getSetting().save('div#settingOther')">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td></tr>
</table>

</div>

<div class="hide Setting" id="settingUpload">
<table cellspcing="2" width="100%">
<tr><td colspan="4">
img0ch独自の設定です。<br>
各設定値を入力して[設定]ボタンを押してください。
<ul>
<li>
「掲示板の形態」の値はpictureでレスにおけるアップロードが、<br />
newsでスレッドにおけるアップロードが可能になります。<br />
noneでアップロード不可能になり、SETTING.TXTから値を隠します。<br />
それ以外の値はアップロード不可能になりますが、<br />
SETTING.TXTから値を見ることが出来ます。
</li>
<li>「添付ファイルの最大サイズ」はbyte単位で設定してください。</li>
<li>
「一つのスレッドにおけるサムネイル表示レス範囲」の範囲外で<br />
画像が張られているレスはリンク表示になります。
</li>
<li>
「画像の縦の最大表示サイズ」および「画像の横の最大表示サイズ」は<br />
ピクセル単位で設定してください。
</li>
<li>
「アップロードを許可する拡張子に」カンマ(,)を含むことは出来ません。<br />
カンマを含むと改行として認識され、無効にされます。
</li>
</ul>
</td></tr>
<tr><td colspan="4"><hr></td></tr>
<tr><td class="DetailTitle">掲示板の形態</td>
<td><input type="text" size="16" name="BBS_MODE" value="" /></td>
<td class="DetailTitle">添付ファイル最大保持数</td>
<td><input type="text" size="16" name="BBS_IMG_FILEMAX" value="" /></td></tr>
<tr><td class="DetailTitle">添付ファイルの最大サイズ</td>
<td><input type="text" size="16" name="BBS_IMG_MAX_SIZE" value="" /></td>
<td class="DetailTitle">ファイルを添付してから次のファイルが添付可能になるまでのレス数</td>
<td><input type="text" size="16" name="BBS_IMG_RENZOKU" value="" /></td></tr>
<tr><td class="DetailTitle">一つのスレッドにおけるサムネイル表示レス範囲</td>
<td><input type="text" size="8" name="BBS_IMG_THUMBNAIL_MAX" value="" /></td>
<td class="DetailTitle">画像の横の最大表示</td>
<td><input type="text" size="8" name="BBS_IMG_THUMBNAIL_X" value="" /></td></tr>
<tr><td class="DetailTitle">画像の縦の最大表示サイズ</td>
<td><input type="text" size="8" name="BBS_IMG_THUMBNAIL_Y" value="" /></td>
<td class="DetailTitle">サムネイルを表示させる位置</td>
<td><input type="text" size="8" name="BBS_IMG_THUMBNAIL_Z" value="" /></td></tr>
<tr><td class="DetailTitle">アップロードされたファイル名を表示する</td>
<td><input type="checkbox" name="BBS_IMG_DECODE_FILENAME" value="checked" />表示する</td>
<td class="DetailTitle">携帯からのメール投稿を許可する</td>
<td><input type="checkbox" name="BBS_ACCEPT_MAILPOST" value="checked" />許可する</td></tr>
<tr><td class="DetailTitle">アップロード時に削除キーを必須にする</td>
<td><input type="checkbox" name="BBS_IMG_REQUIRE_REMOVE_KEY" value="checked" />必須にする</td>
<td class="DetailTitle">アップロード時にダウンロードキーを必須にする</td>
<td><input type="checkbox" name="BBS_IMG_REQUIRE_DOWNLOAD_KEY" value="checked" />必須にする</td></tr>
<tr><td class="DetailTitle">スレッド作成時にファイルのアップロードを許可する</td>
<td><input type="checkbox" name="BBS_IMG_UPLOAD_THREAD" value="checked" />許可</td>
<td class="DetailTitle">ファイルの有効期限(秒単位：0で無限)</td>
<td><input type="text" size="8" name="BBS_IMG_EXPIRES" value="" /></td></tr>
<tr><td class="DetailTitle">アップロードを許可する拡張子</td>
<td>
<textarea name="BBS_IMG_ALLOWED_EXT" cols="10" rows="5"></textarea>
</td>
<td></td>
</tr>
<tr><td colspan="4"><hr></td></tr>
<tr><td colspan="4" align="right">
<button onclick="Zeromin.getSetting().save('div#settingUpload')">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
</td></tr>
</table>

</div>

</div><!-- div#settingRoot -->


<!-- スレッド一覧を表示するコンテナ -->
<div class="hide Container" id="subjectRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
subject.txtに存在するスレッドを表示しています。<br /><br />
不可視スレッド(subject.txtにないのに書き込めるスレッド)がある場合subject.txtを再生成してください。<br />
不可視スレッドはプールから復帰したスレッドも書き込める状態であれば該当します。
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getBBS().getSubject(null, null, this.value)"
/>
</div>

<div>
<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('subjectTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('subjectTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">スレッド名</th>
<th class="DetailTitle">スレッドキー</th>
<th class="DetailTitle">レス数</td></th>
</tr>
</thead>
<tbody id="subjectTable"></tbody>
</table>

<hr>
<div class="alignRight">
<select name="M" onchange="Zeromin.getSubject().sendCommand(this)">
<option value="null">選択されたスレッドを...</option>
<option value="stop" title="指定されたスレッドを停止させます。停止されていないスレッドのみ有効です。">停止</option>
<option value="restart" title="指定されたスレッドを再開させます。停止されたスレッドのみ有効です。">再開</option>
<option value="pool" title="指定されたスレッドをプール(DAT落ち)させます。">プーリング</option>
<option value="remove" title="指定されたスレッドを削除します。削除すると二度と復活しませんので注意してください。">削除</option>
</select>
</div>

</div><!-- div#subjectRoot -->


<!-- レス一覧を表示するコンテナ -->
<div class="hide Container" id="threadRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
「<span id="threadSubject"></span>」のレスを表示しています。<br />
レス中の本文をダブルクリックするとレスの編集画面に移動します。
</div>

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="10"
  onblur="Zeromin.getThread().load(this.value)"
/>
</div><!-- alignRight -->

<div>
<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('threadTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('threadTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">Contents</th>
</tr>
</thead>
<tbody id="threadTable"></tbody>
</table>
<hr />

<div class="alignRight">
<select name="M" onchange="Zeromin.getThread().sendCommand(this)">
<option value="null">選択されたレスを...</option>
<option value="replace" title="指定されたレスを削除します。">通常削除(あぼ〜ん)</option>
<option value="erase" title="指定されたレスをなかったこととして削除します。">透明削除(透明あぼ〜ん)</option>
<option value="removeFile" title="指定されたレスのアップロードファイルのみを削除します。">ファイル削除(ファイルあぼ〜ん)</option>
</select>
</div>

</div><!-- div#threadRoot -->


<!-- スレッドの自動プーリング画面を表示するコンテナ -->
<div class="hide Container" id="threadAPForm">

<div class="State"></div>
<div class="Bread"></div>

<div>
ここでは条件に当てはまるスレッドを一括してプールに送ります(ＤＡＴ落ち)。<br>
以下の条件設定を行って「確認」または「実行」を押してください。<br>
チェックボックスにチェックが入った条件指定のみ有効です。<br>
<ul>
<li>「確認」は指定された条件からプール送りの対象となるスレッドを表示します。プール送りは実行されません。</li>
<li>「実行」は実際に指定された条件に当てはまるスレッドを一括プールに送ります。</li>
</ul>
<hr />
</div>

<table border="0" cellspacing="2" width="100%">
<tr>
<td class="DetailTitle">条件</td>
<td class="DetailTitle">条件設定値</td>
</tr>
<tr>
<td>
<input type="checkbox" name="byDate" value="1" />
最終書き込み
</td>
<td>
最終書き込みが
<input type="text" size="4" name="date" value="30" />日以前
</td>
</tr>
<tr>
<td>
<input type="checkbox" name="byPos" value="1" />
スレッド位置
</td>
<td>
スレッド位置が
<input type="text" size="4" name="pos" value="500" />
以降
</td>
</tr>
<tr>
<td>
<input type=checkbox name="byRes" value="1" />
レス数
</td>
<td>
レス数が
<input type=text size="4" name="res" value="1000" />
以上
</td>
</tr>
<tr>
<td>
<input type=checkbox name="byWritable" value="1" />
書き込み不可能のスレッド
</td>
<td>
スレッドが停止・または移転されているもの
</td>
</tr>
<tr>
<td colspan="2"><hr /></td>
</tr>
<tr>
<td colspan="2">
<textarea id="resultOfAP" readonly="readonly" cols="80" rows="7">
ここでは「確認」によってプールされる対象のスレッドを表示します。
</textarea>
</td>
</tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getBBS().getPool().prepareAP()">
&nbsp;&nbsp;確認&nbsp;&nbsp;
</button>
<button onclick="Zeromin.getBBS().getPool().executeAP()">
&nbsp;&nbsp;実行&nbsp;&nbsp;
</button>
</td></tr>
</table>

</div><!-- div#threadAutopoolForm -->


<!-- レス編集画面を表示するコンテナ -->
<div class="hide Container" id="threadForm">

<div class="State"></div>
<div class="Bread"></div>

<div>
ここでは指定されたレスを編集することが出来ます。<br />
メール欄と本文が変更可能です。日付・IDは編集することが出来ません。<br />
名前欄はシステム設定によって可能になります。<br />
<br />
編集すると元の行の長さと同一でない場合DATの大きさが変わってしまい、<br />
専用ブラウザがDATの大きさを正しくするように再取得する必要が出てくるので、<br />
必要最小限で編集を行うようにしてください。
</div>

<table border="0" cellspacing="2" width="100%">
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">名前</td>
<td><input type="text" size="50" value="" name="FROM" /></td>
</tr>
<tr>
<td class="DetailTitle">メール</td>
<td><input type="text" size="50" value="" name="mail" /></td>
</tr>
<tr>
<td class="DetailTitle">日付・ID</td>
<td><span id="articleDate"></span></td>
</tr>
<tr>
<td class="DetailTitle">本文</td>
<td><textarea name="MESSAGE" cols="70" rows="10"></textarea></td>
</tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getThread().save()">
&nbsp;&nbsp;保存&nbsp;&nbsp;
</button>
<input type="hidden" name="resno" value="" />
</td>
</tr>
</table>

</div><!-- div#threadForm -->


<!-- レス編集画面を表示するコンテナ -->
<div class="hide Container" id="threadIXForm">

<div class="State"></div>
<div class="Bread"></div>

<div>
ここでは条件に当てはまるスレッドをインポートまたはエクスポートします。<br />
<ul>
<li>
インポートは*.dat、*.tar.gz、*.zipのファイルを掲示板内に取り込みます。<br />
*.tar.gz及び*.zipの中身は*.datだけが取り出されます。
</li>
<li>エクスポートは全てのdatを*.tar.gzで圧縮して書き出します。</li>
</ul>
<hr />
</div>

<div id="threadImport">
スレッドのインポート
<form id="threadImportForm" action="" onsubmit="Zeromin.getSubject().doImport(); return false">
<input type="file" name="file" value="" />
<input type="hidden" name="bbs" value="" />
<input type="hidden" name="I" value="" />
<input type="hidden" name="P" value="" />
<input type="hidden" name="C" value="thread" />
<input type="hidden" name="M" value="doImport" />
<input type="hidden" name="js" value="" />
<input type="submit" value="インポート">
</form>
<hr>
</div>

<div id="threadExport">
<a href="javascript:void(0)" onclick="Zeromin.getSubject().doExport()">
スレッドのエクスポートを行う
</a>
</div>

<div>&nbsp;</div>

</div><!-- div#threadIXForm -->


<div class="hide Container" id="userGroupRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
Zerominに登録されているユーザーグループを表示しています。

<div class="alignRight">
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getUgroup().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
表示数
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('ugroupTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('ugroupTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">名前</th>
<th class="DetailTitle">有効範囲</th>
<th class="DetailTitle">所属数</th>
</tr>
</thead>
<tbody id="userGroupTable"></tbody>
</table>
<hr />

<div class="alignRight">
<button onclick="Zeromin.getUgroup().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

</div><!-- div#userGroupRoot -->


<div class="hide Container" id="userGroupForm">

<div class="hide State"></div>
<div class="Bread"></div>

<table class="Table" border="0" cellspacing="2">
<tr>
<td colspan="2">
管理ユーザーのグループを設定します。<br />
<span class="red">*</span>は記入或いは選択必須の項目です。<br />
各項目を設定して[設定]ボタンを押してください。<br />
<br />
Tip.<br />
権限情報はCTRLキーを押しながらマウスの<br />
左クリックを押すことで個別に選択することが出来ます。<br />
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">
グループ名<span class="red">*</span>
</td>
<td>
<input type="text" size="30" name="name" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">
有効範囲(掲示板レベル)<span class="red">*</span>
</td>
<td>
<input type="radio" name="ugroup_all" value="1" />全ての掲示板で有効にする<br />
<input type="radio" name="ugroup_all" value="0" checked="checked" />以下の掲示板で有効にする<br />
<select class="bbsSelect" size="5" name="bbs" multiple="multiple"></select>
</td>
</tr>
<tr>
<td class="DetailTitle">権限設定</td>
<td>
<select name="privilege" size="10" multiple="multiple">
<optgroup id="ugroupPrivilegeUser" label="ユーザー">
<option value="1">アカウント作成</option>
<option value="2">アカウント編集</option>
<option value="4">アカウント削除</option>
<option value="8">グループ作成</option>
<option value="16">グループ編集</option>
<option value="32">グループ削除</option>
</optgroup>
<optgroup id="ugroupPrivilegeCap" label="キャップ">
<option value="1">アカウント作成</option>
<option value="2">アカウント編集</option>
<option value="4">アカウント削除</option>
<option value="8">グループ作成</option>
<option value="16">グループ編集</option>
<option value="32">グループ削除</option>
</optgroup>
<optgroup id="ugroupPrivilegeBBS" label="掲示板">
<option value="1">作成</option>
<option value="2">インデックス更新</option>
<option value="4">削除</option>
<option value="8">情報更新</option>
</optgroup>
<optgroup id="ugroupPrivilegeSetting" label="掲示板設定">
<option value="1">基本的で重要な設定</option>
<option value="2">表示色の設定</option>
<option value="4">投稿制限の設定</option>
<option value="8">以上に当てはまらない設定</option>
<option value="16">0ch独自の設定</option>
<option value="32">img0ch独自の設定</option>
<option value="64">掲示板設定の継承</option>
</optgroup>
<optgroup id="ugroupPrivilegeSubject" label="サブジェクト">
<option value="1">更新(再構築)</option>
<option value="2">復帰(再生成)</option>
</optgroup>
<optgroup id="ugroupPrivilegeThread" label="スレッド">
<option value="1">停止</option>
<option value="2">再開</option>
<option value="4">移動</option>
<option value="8">削除</option>
</optgroup>
<optgroup id="ugroupPrivilegePool" label="プールスレッド">
<option value="1">作成</option>
<option value="2">復帰</option>
<option value="4">削除</option>
</optgroup>
<optgroup id="ugroupPrivilegeArchive" label="過去ログ">
<option value="1">作成</option>
<option value="2">削除</option>
<option value="4">インデックス更新</option>
</optgroup>
<optgroup id="ugroupPrivilegeRes" label="レス">
<option value="1">通常削除(あぼーん)</option>
<option value="2">透明削除(透明あぼーん)</option>
<option value="4">編集</option>
</optgroup>
<optgroup id="ugroupPrivilegeMeta" label="メタデータ">
<option value="1">ローカルルール(head.txt)</option>
<option value="2">メタ</option>
<option value="4">フッター(foot.txt)</option>
<option value="8">バナー全般</option>
</optgroup>
<optgroup id="ugroupPrivilegeControl" label="書き込み制限">
<option value="1">アクセス制限登録</option>
<option value="2">アクセス制限解除</option>
<option value="4">NGワード登録</option>
<option value="8">NGワード編集</option>
<option value="16">NGワード削除</option>
</optgroup>
<optgroup id="ugroupPrivilegeCategory" label="カテゴリ">
<option value="1">作成</option>
<option value="2">編集</option>
<option value="4">削除</option>
</optgroup>
<optgroup id="ugroupPrivilegeView" label="ログ閲覧">
<option value="1">エラー</option>
<option value="2">スレッド作成</option>
<option value="4">ホスト</option>
</optgroup>
<optgroup id="ugroupPrivilegePlugin" label="プラグイン">
<option value="1">更新</option>
<option value="2">設定</option>
</optgroup>
</select>
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td colspan="2" align="right">
<button onclick="Zeromin.getUgroup().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
<input type="hidden" name="id" value="" />
</td>
</tr>
</table>

</div><!-- div#userGroupForm -->


<!-- ユーザー一覧を表示するコンテナ -->
<div class="hide Container" id="userRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
Zerominに登録されているユーザーを表示しています。

<div class="alignRight">
表示数
<input type="text" name="entries" size="4" value="15"
  onblur="Zeromin.getUser().load(this.value)"
/>
</div><!-- alignRight -->

<hr />
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.checkAll(document.getElementById('userTable'))"
   >全て選択する</a> |
<a href="javascript:void(0)"
   onclick="Zeromin.DOM.revertAll(document.getElementById('userTable'))"
   >全ての選択を解除する</a>
</div>

<table class="Table">
<thead>
<tr>
<th class="PrimaryKey DetailTitle">&nbsp;</th>
<th class="DetailTitle">名前</th>
<th class="DetailTitle">メールアドレス</th>
<th class="DetailTitle">所属グループ名</th>
</tr>
</thead>
<tbody id="userTable"></tbody>
</table>
<hr />

<div class="alignRight">
<button onclick="Zeromin.getUser().remove()">
&nbsp;&nbsp;削除&nbsp;&nbsp;
</button>
</div>

</div><!-- div#userRoot -->


<div class="hide Container" id="userForm">

<div class="hide State"></div>
<div class="Bread"></div>

<table class="Table" border="0" cellspacing="2">
<tr>
<td colspan="2">
管理ユーザーのアカウントを新規に発行します。<br />
<span class="red">*</span>は記入或いは選択必須の項目です。<br />
各項目を設定して[設定]ボタンを押してください。
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr>
<td class="DetailTitle">
ユーザ名<span class="red">*</span>
</td>
<td>
<input type="text" size="30" name="name" value="" /></td>
</tr>
<tr>
<td class="DetailTitle">
連絡先(メールアドレス)<span class="red">*</span>
</td>
<td>
<input type="text" size="30" name="mail" value="" /></td>
</tr>
<tr>
<td class="DetailTitle">
パスワード<span class="red">*</span>
</td>
<td>
<input type="password" size="30" name="pass" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">
パスワード(確認用)<span class="red">*</span>
</td>
<td>
<input type="password" size="30" name="confirm" value="" />
</td>
</tr>
<tr>
<td class="DetailTitle">
所属グループ<span class="red">*</span>
</td>
<td>
<select class="ugroupSelect" name="group"></select>
</td>
</tr>
<tr><td colspan="2"><hr /></td></tr>
<tr><td colspan="2" align="right">
<button onclick="Zeromin.getUser().save()">
&nbsp;&nbsp;設定&nbsp;&nbsp;
</button>
<input type="hidden" name="id" value="" />
</td></tr>
</table>

</div><!-- div#userForm -->


<div class="hide Container" id="systemEnvironmentRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
設置しているサーバーの関連情報を表示しています。<br />
ここではモジュールの再読み込み及びキャッシュの削除を行うことが出来ます。<br />
<br />
<a href="javascript:void(0)" onclick="Zeromin.getSystem().removeTemplateCache()">
テンプレートのキャッシュを全て削除する
</a><br />
<a href="javascript:void(0)" onclick="Zeromin.getSystem().refresh()">
モジュールを全て再読み込みする(mod_perl環境のみ有効)
</a>
<hr />
</div>

<table class="Table" border="0" cellspacing="2">
<tr>
<td class="DetailTitle">Perlのバージョン</td>
<td id="envPerlVersion"></td>
</tr>
<tr>
<td class="DetailTitle">サーバーの基本ソフトウェア(OS)名</td>
<td id="envServerOS"></td>
</tr>
<tr>
<td class="DetailTitle">サーバーのホスト名</td>
<td id="envServerName"></td>
</tr>
<tr>
<td class="DetailTitle">サーバーのポート番号</td>
<td id="envServerPort"></td>
</tr>
<tr>
<td class="DetailTitle">設置パス</td>
<td id="envBasePath"></td>
</tr>
<tr>
<td class="DetailTitle">Img0chのバージョン</td>
<td id="envImg0chVersion"></td>
</tr>
</table>

</div><!-- div#systemEnvironmentRoot -->


<div class="hide Container" id="systemMigrateRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
過去のデータ(2005/12/30以前)を現行版のデータに移行します。<br />
管理権限を持つグループに所属するユーザーのみ実行可能です。

<div id="migrateSelect">
<p>
移行するデータ<br />
<input type="checkbox" name="archive" value="1" id="migrateArchive" />
<label for="migrateArchive">過去ログ</label><br />
<input type="checkbox" name="pool" value="1" id="migratePool" />
<label for="migratePool">プールスレッド</label><br />
<input type="checkbox" name="banner" value="1" id="migrateBanner" />
<label for="migrateBanner">バナー</label><br />
<input type="checkbox" name="category" value="1" id="migrateCategory" />
<label for="migrateCategory">カテゴリ</label><br />
<input type="checkbox" name="user" value="1" id="migrateUser" />
<label for="migrateUser">ユーザー</label><br />
<input type="checkbox" name="cap" value="1" id="migrateCap" />
<label for="migrateCap">キャップ</label><br />
<input type="checkbox" name="hostlog" value="1" id="migrateHostlog" />
<label for="migrateHostlog">ホストログ</label><br />
<input type="checkbox" name="threadlog" value="1" id="migrateThreadlog" />
<label for="migrateThreadlog">スレッドログ</label><br />
</p>
<button onclick="Zeromin.getSystem().startMigration()">データ移行を開始する</button>
</div>

</div>

</div><!-- div#systemMigrateRoot -->


<div class="hide Container" id="systemRepositoryRoot">

<div class="hide State"></div>
<div class="Bread"></div>

<div>
レポジトリのバックアップ(以下スナップショット)を作成します。<br />
掲示板作成が可能な権限を持つユーザーグループに属するユーザーがこの操作を実行できます。<br />
<br />
<a href="javascript:void(0)" onclick="Zeromin.getSystem().makeRepositorySnapshot()">
スナップショットを作成する
</a>
<input id="repositorySnapshotWithZip" name="zip" value="1" type="checkbox" />ZIP形式で作成する

<p>
スナップショットはRepositoryRootディレクトリ内の<br />
<strong>img0ch-repository-dump.tar.gz</strong><br />
<br />
ZIP形式で作成した場合<br />
<strong>img0ch-repository-dump.zip</strong><br />
<br />
に保存されます。このファイルをSSHまたはFTP経由でダウンロードしてください。
</p>

</div>

</div><!-- div#systemRepositoryRoot -->


</td>
</tr>
</table><!-- table#layoutContainer -->

<!-- ヘッダー -->
<div id="footer">
Copyright 2001-2007 0ch BBS, 2003-2007 img0ch BBS -
Loggin User: <strong id="loggedUser">NONE</strong><br />
Build Version: <strong><?cs var:html_escape(VERSION) ?></strong>
</div>

</body>

</html>

